==> certmanager-model-v1alpha3-6.9.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha3/ACMEChallengeSolverHTTP01IngressFluent.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ACMEChallengeSolverHTTP01IngressFluent<A extends ACMEChallengeSolverHTTP01IngressFluent<A>> extends BaseFluent<A>{
  public ACMEChallengeSolverHTTP01IngressFluent() {
  }
  
  public ACMEChallengeSolverHTTP01IngressFluent(ACMEChallengeSolverHTTP01Ingress instance) {
    this.copyInstance(instance);
  }
  private String className;
  private ACMEChallengeSolverHTTP01IngressTemplateBuilder ingressTemplate;
  private String name;
  private ACMEChallengeSolverHTTP01IngressPodTemplateBuilder podTemplate;
  private String serviceType;
  
  protected void copyInstance(ACMEChallengeSolverHTTP01Ingress instance) {
    instance = (instance != null ? instance : new ACMEChallengeSolverHTTP01Ingress());
  
    if (instance != null) {
        this.withClassName(instance.getClassName());
        this.withIngressTemplate(instance.getIngressTemplate());
        this.withName(instance.getName());
        this.withPodTemplate(instance.getPodTemplate());
        this.withServiceType(instance.getServiceType());
        this.withClassName(instance.getClassName());
        this.withIngressTemplate(instance.getIngressTemplate());
        this.withName(instance.getName());
        this.withPodTemplate(instance.getPodTemplate());
        this.withServiceType(instance.getServiceType());
      }
  }
  
  public String getClassName() {
    return this.className;
  }
  
  public A withClassName(String className) {
    this.className=className; return (A) this;
  }
  
  public boolean hasClassName() {
    return this.className != null;
  }
  
  public ACMEChallengeSolverHTTP01IngressTemplate buildIngressTemplate() {
    return this.ingressTemplate!=null ?this.ingressTemplate.build():null;
  }
  
  public A withIngressTemplate(ACMEChallengeSolverHTTP01IngressTemplate ingressTemplate) {
    _visitables.get("ingressTemplate").remove(this.ingressTemplate);
    if (ingressTemplate!=null){ this.ingressTemplate= new ACMEChallengeSolverHTTP01IngressTemplateBuilder(ingressTemplate); _visitables.get("ingressTemplate").add(this.ingressTemplate);} else { this.ingressTemplate = null; _visitables.get("ingressTemplate").remove(this.ingressTemplate); } return (A) this;
  }
  
  public boolean hasIngressTemplate() {
    return this.ingressTemplate != null;
  }
  
  public IngressTemplateNested<A> withNewIngressTemplate() {
    return new IngressTemplateNested(null);
  }
  
  public IngressTemplateNested<A> withNewIngressTemplateLike(ACMEChallengeSolverHTTP01IngressTemplate item) {
    return new IngressTemplateNested(item);
  }
  
  public IngressTemplateNested<A> editIngressTemplate() {
    return withNewIngressTemplateLike(java.util.Optional.ofNullable(buildIngressTemplate()).orElse(null));
  }
  
  public IngressTemplateNested<A> editOrNewIngressTemplate() {
    return withNewIngressTemplateLike(java.util.Optional.ofNullable(buildIngressTemplate()).orElse(new ACMEChallengeSolverHTTP01IngressTemplateBuilder().build()));
  }
  
  public IngressTemplateNested<A> editOrNewIngressTemplateLike(ACMEChallengeSolverHTTP01IngressTemplate item) {
    return withNewIngressTemplateLike(java.util.Optional.ofNullable(buildIngressTemplate()).orElse(item));
  }
  
  public String getName() {
    return this.name;
  }
  
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  
  public boolean hasName() {
    return this.name != null;
  }
  
  public ACMEChallengeSolverHTTP01IngressPodTemplate buildPodTemplate() {
    return this.podTemplate!=null ?this.podTemplate.build():null;
  }
  
  public A withPodTemplate(ACMEChallengeSolverHTTP01IngressPodTemplate podTemplate) {
    _visitables.get("podTemplate").remove(this.podTemplate);
    if (podTemplate!=null){ this.podTemplate= new ACMEChallengeSolverHTTP01IngressPodTemplateBuilder(podTemplate); _visitables.get("podTemplate").add(this.podTemplate);} else { this.podTemplate = null; _visitables.get("podTemplate").remove(this.podTemplate); } return (A) this;
  }
  
  public boolean hasPodTemplate() {
    return this.podTemplate != null;
  }
  
  public PodTemplateNested<A> withNewPodTemplate() {
    return new PodTemplateNested(null);
  }
  
  public PodTemplateNested<A> withNewPodTemplateLike(ACMEChallengeSolverHTTP01IngressPodTemplate item) {
    return new PodTemplateNested(item);
  }
  
  public PodTemplateNested<A> editPodTemplate() {
    return withNewPodTemplateLike(java.util.Optional.ofNullable(buildPodTemplate()).orElse(null));
  }
  
  public PodTemplateNested<A> editOrNewPodTemplate() {
    return withNewPodTemplateLike(java.util.Optional.ofNullable(buildPodTemplate()).orElse(new ACMEChallengeSolverHTTP01IngressPodTemplateBuilder().build()));
  }
  
  public PodTemplateNested<A> editOrNewPodTemplateLike(ACMEChallengeSolverHTTP01IngressPodTemplate item) {
    return withNewPodTemplateLike(java.util.Optional.ofNullable(buildPodTemplate()).orElse(item));
  }
  
  public String getServiceType() {
    return this.serviceType;
  }
  
  public A withServiceType(String serviceType) {
    this.serviceType=serviceType; return (A) this;
  }
  
  public boolean hasServiceType() {
    return this.serviceType != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ACMEChallengeSolverHTTP01IngressFluent that = (ACMEChallengeSolverHTTP01IngressFluent) o;
    if (!java.util.Objects.equals(className, that.className)) return false;
  
    if (!java.util.Objects.equals(ingressTemplate, that.ingressTemplate)) return false;
  
    if (!java.util.Objects.equals(name, that.name)) return false;
  
    if (!java.util.Objects.equals(podTemplate, that.podTemplate)) return false;
  
    if (!java.util.Objects.equals(serviceType, that.serviceType)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(className,  ingressTemplate,  name,  podTemplate,  serviceType,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (className != null) { sb.append("className:"); sb.append(className + ","); }
    if (ingressTemplate != null) { sb.append("ingressTemplate:"); sb.append(ingressTemplate + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (podTemplate != null) { sb.append("podTemplate:"); sb.append(podTemplate + ","); }
    if (serviceType != null) { sb.append("serviceType:"); sb.append(serviceType); }
    sb.append("}");
    return sb.toString();
  }
  public class IngressTemplateNested<N> extends ACMEChallengeSolverHTTP01IngressTemplateFluent<IngressTemplateNested<N>> implements Nested<N>{
    IngressTemplateNested(ACMEChallengeSolverHTTP01IngressTemplate item) {
      this.builder = new ACMEChallengeSolverHTTP01IngressTemplateBuilder(this, item);
    }
    ACMEChallengeSolverHTTP01IngressTemplateBuilder builder;
    
    public N and() {
      return (N) ACMEChallengeSolverHTTP01IngressFluent.this.withIngressTemplate(builder.build());
    }
    
    public N endIngressTemplate() {
      return and();
    }
    
  
  }
  public class PodTemplateNested<N> extends ACMEChallengeSolverHTTP01IngressPodTemplateFluent<PodTemplateNested<N>> implements Nested<N>{
    PodTemplateNested(ACMEChallengeSolverHTTP01IngressPodTemplate item) {
      this.builder = new ACMEChallengeSolverHTTP01IngressPodTemplateBuilder(this, item);
    }
    ACMEChallengeSolverHTTP01IngressPodTemplateBuilder builder;
    
    public N and() {
      return (N) ACMEChallengeSolverHTTP01IngressFluent.this.withPodTemplate(builder.build());
    }
    
    public N endPodTemplate() {
      return and();
    }
    
  
  }

}

==> certmanager-model-v1alpha3-6.9.2-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha3/ACMEChallengeSolverHTTP01IngressFluent.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ACMEChallengeSolverHTTP01IngressFluent<A extends ACMEChallengeSolverHTTP01IngressFluent<A>> extends BaseFluent<A>{
  public ACMEChallengeSolverHTTP01IngressFluent() {
  }
  
  public ACMEChallengeSolverHTTP01IngressFluent(ACMEChallengeSolverHTTP01Ingress instance) {
    this.copyInstance(instance);
  }
  private String className;
  private ACMEChallengeSolverHTTP01IngressTemplateBuilder ingressTemplate;
  private String name;
  private ACMEChallengeSolverHTTP01IngressPodTemplateBuilder podTemplate;
  private String serviceType;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(ACMEChallengeSolverHTTP01Ingress instance) {
    instance = (instance != null ? instance : new ACMEChallengeSolverHTTP01Ingress());
    if (instance != null) {
          this.withClassName(instance.getClassName());
          this.withIngressTemplate(instance.getIngressTemplate());
          this.withName(instance.getName());
          this.withPodTemplate(instance.getPodTemplate());
          this.withServiceType(instance.getServiceType());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public String getClassName() {
    return this.className;
  }
  
  public A withClassName(String className) {
    this.className = className;
    return (A) this;
  }
  
  public boolean hasClassName() {
    return this.className != null;
  }
  
  public ACMEChallengeSolverHTTP01IngressTemplate buildIngressTemplate() {
    return this.ingressTemplate != null ? this.ingressTemplate.build() : null;
  }
  
  public A withIngressTemplate(ACMEChallengeSolverHTTP01IngressTemplate ingressTemplate) {
    this._visitables.remove("ingressTemplate");
    if (ingressTemplate != null) {
        this.ingressTemplate = new ACMEChallengeSolverHTTP01IngressTemplateBuilder(ingressTemplate);
        this._visitables.get("ingressTemplate").add(this.ingressTemplate);
    } else {
        this.ingressTemplate = null;
        this._visitables.get("ingressTemplate").remove(this.ingressTemplate);
    }
    return (A) this;
  }
  
  public boolean hasIngressTemplate() {
    return this.ingressTemplate != null;
  }
  
  public IngressTemplateNested<A> withNewIngressTemplate() {
    return new IngressTemplateNested(null);
  }
  
  public IngressTemplateNested<A> withNewIngressTemplateLike(ACMEChallengeSolverHTTP01IngressTemplate item) {
    return new IngressTemplateNested(item);
  }
  
  public IngressTemplateNested<A> editIngressTemplate() {
    return withNewIngressTemplateLike(java.util.Optional.ofNullable(buildIngressTemplate()).orElse(null));
  }
  
  public IngressTemplateNested<A> editOrNewIngressTemplate() {
    return withNewIngressTemplateLike(java.util.Optional.ofNullable(buildIngressTemplate()).orElse(new ACMEChallengeSolverHTTP01IngressTemplateBuilder().build()));
  }
  
  public IngressTemplateNested<A> editOrNewIngressTemplateLike(ACMEChallengeSolverHTTP01IngressTemplate item) {
    return withNewIngressTemplateLike(java.util.Optional.ofNullable(buildIngressTemplate()).orElse(item));
  }
  
  public String getName() {
    return this.name;
  }
  
  public A withName(String name) {
    this.name = name;
    return (A) this;
  }
  
  public boolean hasName() {
    return this.name != null;
  }
  
  public ACMEChallengeSolverHTTP01IngressPodTemplate buildPodTemplate() {
    return this.podTemplate != null ? this.podTemplate.build() : null;
  }
  
  public A withPodTemplate(ACMEChallengeSolverHTTP01IngressPodTemplate podTemplate) {
    this._visitables.remove("podTemplate");
    if (podTemplate != null) {
        this.podTemplate = new ACMEChallengeSolverHTTP01IngressPodTemplateBuilder(podTemplate);
        this._visitables.get("podTemplate").add(this.podTemplate);
    } else {
        this.podTemplate = null;
        this._visitables.get("podTemplate").remove(this.podTemplate);
    }
    return (A) this;
  }
  
  public boolean hasPodTemplate() {
    return this.podTemplate != null;
  }
  
  public PodTemplateNested<A> withNewPodTemplate() {
    return new PodTemplateNested(null);
  }
  
  public PodTemplateNested<A> withNewPodTemplateLike(ACMEChallengeSolverHTTP01IngressPodTemplate item) {
    return new PodTemplateNested(item);
  }
  
  public PodTemplateNested<A> editPodTemplate() {
    return withNewPodTemplateLike(java.util.Optional.ofNullable(buildPodTemplate()).orElse(null));
  }
  
  public PodTemplateNested<A> editOrNewPodTemplate() {
    return withNewPodTemplateLike(java.util.Optional.ofNullable(buildPodTemplate()).orElse(new ACMEChallengeSolverHTTP01IngressPodTemplateBuilder().build()));
  }
  
  public PodTemplateNested<A> editOrNewPodTemplateLike(ACMEChallengeSolverHTTP01IngressPodTemplate item) {
    return withNewPodTemplateLike(java.util.Optional.ofNullable(buildPodTemplate()).orElse(item));
  }
  
  public String getServiceType() {
    return this.serviceType;
  }
  
  public A withServiceType(String serviceType) {
    this.serviceType = serviceType;
    return (A) this;
  }
  
  public boolean hasServiceType() {
    return this.serviceType != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ACMEChallengeSolverHTTP01IngressFluent that = (ACMEChallengeSolverHTTP01IngressFluent) o;
    if (!java.util.Objects.equals(className, that.className)) return false;
    if (!java.util.Objects.equals(ingressTemplate, that.ingressTemplate)) return false;
    if (!java.util.Objects.equals(name, that.name)) return false;
    if (!java.util.Objects.equals(podTemplate, that.podTemplate)) return false;
    if (!java.util.Objects.equals(serviceType, that.serviceType)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(className,  ingressTemplate,  name,  podTemplate,  serviceType,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (className != null) { sb.append("className:"); sb.append(className + ","); }
    if (ingressTemplate != null) { sb.append("ingressTemplate:"); sb.append(ingressTemplate + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (podTemplate != null) { sb.append("podTemplate:"); sb.append(podTemplate + ","); }
    if (serviceType != null) { sb.append("serviceType:"); sb.append(serviceType + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class IngressTemplateNested<N> extends ACMEChallengeSolverHTTP01IngressTemplateFluent<IngressTemplateNested<N>> implements Nested<N>{
    IngressTemplateNested(ACMEChallengeSolverHTTP01IngressTemplate item) {
      this.builder = new ACMEChallengeSolverHTTP01IngressTemplateBuilder(this, item);
    }
    ACMEChallengeSolverHTTP01IngressTemplateBuilder builder;
    
    public N and() {
      return (N) ACMEChallengeSolverHTTP01IngressFluent.this.withIngressTemplate(builder.build());
    }
    
    public N endIngressTemplate() {
      return and();
    }
    
  
  }
  public class PodTemplateNested<N> extends ACMEChallengeSolverHTTP01IngressPodTemplateFluent<PodTemplateNested<N>> implements Nested<N>{
    PodTemplateNested(ACMEChallengeSolverHTTP01IngressPodTemplate item) {
      this.builder = new ACMEChallengeSolverHTTP01IngressPodTemplateBuilder(this, item);
    }
    ACMEChallengeSolverHTTP01IngressPodTemplateBuilder builder;
    
    public N and() {
      return (N) ACMEChallengeSolverHTTP01IngressFluent.this.withPodTemplate(builder.build());
    }
    
    public N endPodTemplate() {
      return and();
    }
    
  
  }

}
